# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/ext4.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/ext4.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'protos/perfetto/trace/ftrace/ext4.proto\x12\x0fperfetto.protos\"`\n\x1b\x45xt4DaWriteBeginFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\r\n\x05\x66lags\x18\x05 \x01(\r\"_\n\x19\x45xt4DaWriteEndFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\x0e\n\x06\x63opied\x18\x05 \x01(\r\"Z\n\x1c\x45xt4SyncFileEnterFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0e\n\x06parent\x18\x03 \x01(\x04\x12\x10\n\x08\x64\x61tasync\x18\x04 \x01(\x05\"D\n\x1b\x45xt4SyncFileExitFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03ret\x18\x03 \x01(\x05\"b\n\x1c\x45xt4AllocDaBlocksFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x13\n\x0b\x64\x61ta_blocks\x18\x03 \x01(\r\x12\x13\n\x0bmeta_blocks\x18\x04 \x01(\r\"\xc1\x01\n\x1d\x45xt4AllocateBlocksFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05\x62lock\x18\x03 \x01(\x04\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\x0f\n\x07logical\x18\x05 \x01(\r\x12\r\n\x05lleft\x18\x06 \x01(\r\x12\x0e\n\x06lright\x18\x07 \x01(\r\x12\x0c\n\x04goal\x18\x08 \x01(\x04\x12\r\n\x05pleft\x18\t \x01(\x04\x12\x0e\n\x06pright\x18\n \x01(\x04\x12\r\n\x05\x66lags\x18\x0b \x01(\r\"S\n\x1c\x45xt4AllocateInodeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03\x64ir\x18\x03 \x01(\x04\x12\x0c\n\x04mode\x18\x04 \x01(\r\"Q\n#Ext4BeginOrderedTruncateFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x10\n\x08new_size\x18\x03 \x01(\x03\"U\n\x1c\x45xt4CollapseRangeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0e\n\x06offset\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\x03\"\xca\x01\n\x1d\x45xt4DaReleaseSpaceFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x10\n\x08i_blocks\x18\x03 \x01(\x04\x12\x14\n\x0c\x66reed_blocks\x18\x04 \x01(\x05\x12\x1c\n\x14reserved_data_blocks\x18\x05 \x01(\x05\x12\x1c\n\x14reserved_meta_blocks\x18\x06 \x01(\x05\x12\x1d\n\x15\x61llocated_meta_blocks\x18\x07 \x01(\x05\x12\x0c\n\x04mode\x18\x08 \x01(\r\"\xa8\x01\n\x1d\x45xt4DaReserveSpaceFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x10\n\x08i_blocks\x18\x03 \x01(\x04\x12\x1c\n\x14reserved_data_blocks\x18\x04 \x01(\x05\x12\x1c\n\x14reserved_meta_blocks\x18\x05 \x01(\x05\x12\x0c\n\x04mode\x18\x06 \x01(\r\x12\x11\n\tmd_needed\x18\x07 \x01(\x05\"\xe4\x01\n#Ext4DaUpdateReserveSpaceFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x10\n\x08i_blocks\x18\x03 \x01(\x04\x12\x13\n\x0bused_blocks\x18\x04 \x01(\x05\x12\x1c\n\x14reserved_data_blocks\x18\x05 \x01(\x05\x12\x1c\n\x14reserved_meta_blocks\x18\x06 \x01(\x05\x12\x1d\n\x15\x61llocated_meta_blocks\x18\x07 \x01(\x05\x12\x13\n\x0bquota_claim\x18\x08 \x01(\x05\x12\x0c\n\x04mode\x18\t \x01(\r\"\xcf\x01\n\x1b\x45xt4DaWritePagesFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x12\n\nfirst_page\x18\x03 \x01(\x04\x12\x13\n\x0bnr_to_write\x18\x04 \x01(\x03\x12\x11\n\tsync_mode\x18\x05 \x01(\x05\x12\x11\n\tb_blocknr\x18\x06 \x01(\x04\x12\x0e\n\x06\x62_size\x18\x07 \x01(\r\x12\x0f\n\x07\x62_state\x18\x08 \x01(\r\x12\x0f\n\x07io_done\x18\t \x01(\x05\x12\x15\n\rpages_written\x18\n \x01(\x05\"g\n!Ext4DaWritePagesExtentFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\x04\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\r\n\x05\x66lags\x18\x05 \x01(\r\"^\n\x1c\x45xt4DirectIOEnterFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\x04\x12\n\n\x02rw\x18\x05 \x01(\x05\"j\n\x1b\x45xt4DirectIOExitFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\x04\x12\n\n\x02rw\x18\x05 \x01(\x05\x12\x0b\n\x03ret\x18\x06 \x01(\x05\"G\n\x1c\x45xt4DiscardBlocksFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03\x62lk\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\"]\n$Ext4DiscardPreallocationsFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03len\x18\x03 \x01(\r\x12\x0e\n\x06needed\x18\x04 \x01(\r\"B\n\x18\x45xt4DropInodeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04\x64rop\x18\x03 \x01(\x05\"q\n\x1c\x45xt4EsCacheExtentFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\r\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\x0c\n\x04pblk\x18\x05 \x01(\x04\x12\x0e\n\x06status\x18\x06 \x01(\r\"V\n,Ext4EsFindDelayedExtentRangeEnterFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\r\"\x80\x01\n+Ext4EsFindDelayedExtentRangeExitFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\r\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\x0c\n\x04pblk\x18\x05 \x01(\x04\x12\x0e\n\x06status\x18\x06 \x01(\x04\"r\n\x1d\x45xt4EsInsertExtentFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\r\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\x0c\n\x04pblk\x18\x05 \x01(\x04\x12\x0e\n\x06status\x18\x06 \x01(\x04\"L\n\"Ext4EsLookupExtentEnterFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\r\"\x85\x01\n!Ext4EsLookupExtentExitFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\r\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\x0c\n\x04pblk\x18\x05 \x01(\x04\x12\x0e\n\x06status\x18\x06 \x01(\x04\x12\r\n\x05\x66ound\x18\x07 \x01(\x05\"T\n\x1d\x45xt4EsRemoveExtentFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\x03\"q\n\x17\x45xt4EsShrinkFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x11\n\tnr_shrunk\x18\x02 \x01(\x05\x12\x11\n\tscan_time\x18\x03 \x01(\x04\x12\x12\n\nnr_skipped\x18\x04 \x01(\x05\x12\x0f\n\x07retried\x18\x05 \x01(\x05\"R\n\x1c\x45xt4EsShrinkCountFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x12\n\nnr_to_scan\x18\x02 \x01(\x05\x12\x11\n\tcache_cnt\x18\x03 \x01(\x05\"V\n Ext4EsShrinkScanEnterFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x12\n\nnr_to_scan\x18\x02 \x01(\x05\x12\x11\n\tcache_cnt\x18\x03 \x01(\x05\"T\n\x1f\x45xt4EsShrinkScanExitFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x11\n\tnr_shrunk\x18\x02 \x01(\x05\x12\x11\n\tcache_cnt\x18\x03 \x01(\x05\"D\n\x19\x45xt4EvictInodeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05nlink\x18\x03 \x01(\x05\"\x95\x01\n+Ext4ExtConvertToInitializedEnterFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0e\n\x06m_lblk\x18\x03 \x01(\r\x12\r\n\x05m_len\x18\x04 \x01(\r\x12\x0e\n\x06u_lblk\x18\x05 \x01(\r\x12\r\n\x05u_len\x18\x06 \x01(\r\x12\x0e\n\x06u_pblk\x18\x07 \x01(\x04\"\xc7\x01\n.Ext4ExtConvertToInitializedFastpathFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0e\n\x06m_lblk\x18\x03 \x01(\r\x12\r\n\x05m_len\x18\x04 \x01(\r\x12\x0e\n\x06u_lblk\x18\x05 \x01(\r\x12\r\n\x05u_len\x18\x06 \x01(\r\x12\x0e\n\x06u_pblk\x18\x07 \x01(\x04\x12\x0e\n\x06i_lblk\x18\x08 \x01(\r\x12\r\n\x05i_len\x18\t \x01(\r\x12\x0e\n\x06i_pblk\x18\n \x01(\x04\"\x9f\x01\n(Ext4ExtHandleUnwrittenExtentsFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05\x66lags\x18\x03 \x01(\x05\x12\x0c\n\x04lblk\x18\x04 \x01(\r\x12\x0c\n\x04pblk\x18\x05 \x01(\x04\x12\x0b\n\x03len\x18\x06 \x01(\r\x12\x11\n\tallocated\x18\x07 \x01(\r\x12\x0e\n\x06newblk\x18\x08 \x01(\x04\"P\n\x19\x45xt4ExtInCacheFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\r\x12\x0b\n\x03ret\x18\x04 \x01(\x05\"T\n\x1c\x45xt4ExtLoadExtentFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04pblk\x18\x03 \x01(\x04\x12\x0c\n\x04lblk\x18\x04 \x01(\r\"f\n Ext4ExtMapBlocksEnterFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\r\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\r\n\x05\x66lags\x18\x05 \x01(\r\"\x90\x01\n\x1f\x45xt4ExtMapBlocksExitFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x0c\n\x04pblk\x18\x04 \x01(\x04\x12\x0c\n\x04lblk\x18\x05 \x01(\r\x12\x0b\n\x03len\x18\x06 \x01(\r\x12\x0e\n\x06mflags\x18\x07 \x01(\r\x12\x0b\n\x03ret\x18\x08 \x01(\x05\"b\n\x1c\x45xt4ExtPutInCacheFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\r\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\r\n\x05start\x18\x05 \x01(\x04\"d\n\x1d\x45xt4ExtRemoveSpaceFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05start\x18\x03 \x01(\r\x12\x0b\n\x03\x65nd\x18\x04 \x01(\r\x12\r\n\x05\x64\x65pth\x18\x05 \x01(\x05\"\xc1\x01\n!Ext4ExtRemoveSpaceDoneFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05start\x18\x03 \x01(\r\x12\x0b\n\x03\x65nd\x18\x04 \x01(\r\x12\r\n\x05\x64\x65pth\x18\x05 \x01(\x05\x12\x0f\n\x07partial\x18\x06 \x01(\x03\x12\x12\n\neh_entries\x18\x07 \x01(\r\x12\x0f\n\x07pc_lblk\x18\x08 \x01(\r\x12\x0f\n\x07pc_pclu\x18\t \x01(\x04\x12\x10\n\x08pc_state\x18\n \x01(\x05\"A\n\x17\x45xt4ExtRmIdxFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04pblk\x18\x03 \x01(\x04\"\xba\x01\n\x18\x45xt4ExtRmLeafFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0f\n\x07partial\x18\x03 \x01(\x03\x12\r\n\x05start\x18\x04 \x01(\r\x12\x0f\n\x07\x65\x65_lblk\x18\x05 \x01(\r\x12\x0f\n\x07\x65\x65_pblk\x18\x06 \x01(\x04\x12\x0e\n\x06\x65\x65_len\x18\x07 \x01(\x05\x12\x0f\n\x07pc_lblk\x18\x08 \x01(\r\x12\x0f\n\x07pc_pclu\x18\t \x01(\x04\x12\x10\n\x08pc_state\x18\n \x01(\x05\"a\n\x1c\x45xt4ExtShowExtentFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04pblk\x18\x03 \x01(\x04\x12\x0c\n\x04lblk\x18\x04 \x01(\r\x12\x0b\n\x03len\x18\x05 \x01(\r\"q\n\x1d\x45xt4FallocateEnterFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0e\n\x06offset\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\x03\x12\x0c\n\x04mode\x18\x05 \x01(\x05\x12\x0b\n\x03pos\x18\x06 \x01(\x03\"b\n\x1c\x45xt4FallocateExitFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\x0e\n\x06\x62locks\x18\x04 \x01(\r\x12\x0b\n\x03ret\x18\x05 \x01(\x05\"\x89\x01\n Ext4FindDelallocRangeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04\x66rom\x18\x03 \x01(\r\x12\n\n\x02to\x18\x04 \x01(\r\x12\x0f\n\x07reverse\x18\x05 \x01(\x05\x12\r\n\x05\x66ound\x18\x06 \x01(\x05\x12\x11\n\tfound_blk\x18\x07 \x01(\r\"c\n\x15\x45xt4ForgetFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05\x62lock\x18\x03 \x01(\x04\x12\x13\n\x0bis_metadata\x18\x04 \x01(\x05\x12\x0c\n\x04mode\x18\x05 \x01(\r\"p\n\x19\x45xt4FreeBlocksFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05\x62lock\x18\x03 \x01(\x04\x12\r\n\x05\x63ount\x18\x04 \x01(\x04\x12\r\n\x05\x66lags\x18\x05 \x01(\x05\x12\x0c\n\x04mode\x18\x06 \x01(\r\"l\n\x18\x45xt4FreeInodeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03uid\x18\x03 \x01(\r\x12\x0b\n\x03gid\x18\x04 \x01(\r\x12\x0e\n\x06\x62locks\x18\x05 \x01(\x04\x12\x0c\n\x04mode\x18\x06 \x01(\r\"}\n)Ext4GetImpliedClusterAllocExitFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\x0c\n\x04lblk\x18\x03 \x01(\r\x12\x0c\n\x04pblk\x18\x04 \x01(\x04\x12\x0b\n\x03len\x18\x05 \x01(\r\x12\x0b\n\x03ret\x18\x06 \x01(\x05\"]\n&Ext4GetReservedClusterAllocFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\r\x12\x0b\n\x03len\x18\x04 \x01(\r\"f\n Ext4IndMapBlocksEnterFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04lblk\x18\x03 \x01(\r\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\r\n\x05\x66lags\x18\x05 \x01(\r\"\x90\x01\n\x1f\x45xt4IndMapBlocksExitFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x0c\n\x04pblk\x18\x04 \x01(\x04\x12\x0c\n\x04lblk\x18\x05 \x01(\r\x12\x0b\n\x03len\x18\x06 \x01(\r\x12\x0e\n\x06mflags\x18\x07 \x01(\r\x12\x0b\n\x03ret\x18\x08 \x01(\x05\"S\n\x1a\x45xt4InsertRangeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0e\n\x06offset\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\x03\"h\n\x1d\x45xt4InvalidatepageFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05index\x18\x03 \x01(\x04\x12\x0e\n\x06offset\x18\x04 \x01(\x04\x12\x0e\n\x06length\x18\x05 \x01(\r\"\x81\x01\n\x1b\x45xt4JournalStartFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\n\n\x02ip\x18\x02 \x01(\x04\x12\x0e\n\x06\x62locks\x18\x03 \x01(\x05\x12\x12\n\nrsv_blocks\x18\x04 \x01(\x05\x12\x0f\n\x07nblocks\x18\x05 \x01(\x05\x12\x14\n\x0crevoke_creds\x18\x06 \x01(\x05\"N\n#Ext4JournalStartReservedFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\n\n\x02ip\x18\x02 \x01(\x04\x12\x0e\n\x06\x62locks\x18\x03 \x01(\x05\"r\n\'Ext4JournalledInvalidatepageFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05index\x18\x03 \x01(\x04\x12\x0e\n\x06offset\x18\x04 \x01(\x04\x12\x0e\n\x06length\x18\x05 \x01(\r\"g\n!Ext4JournalledWriteEndFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\x0e\n\x06\x63opied\x18\x05 \x01(\r\"4\n\x18\x45xt4LoadInodeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\"<\n\x1e\x45xt4LoadInodeBitmapFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\r\n\x05group\x18\x02 \x01(\r\"E\n\x1d\x45xt4MarkInodeDirtyFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\n\n\x02ip\x18\x03 \x01(\x04\"9\n\x1b\x45xt4MbBitmapLoadFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\r\n\x05group\x18\x02 \x01(\r\">\n Ext4MbBuddyBitmapLoadFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\r\n\x05group\x18\x02 \x01(\r\"E\n&Ext4MbDiscardPreallocationsFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0e\n\x06needed\x18\x02 \x01(\x05\"m\n\x1b\x45xt4MbNewGroupPaFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x11\n\tpa_pstart\x18\x03 \x01(\x04\x12\x11\n\tpa_lstart\x18\x04 \x01(\x04\x12\x0e\n\x06pa_len\x18\x05 \x01(\r\"m\n\x1b\x45xt4MbNewInodePaFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x11\n\tpa_pstart\x18\x03 \x01(\x04\x12\x11\n\tpa_lstart\x18\x04 \x01(\x04\x12\x0e\n\x06pa_len\x18\x05 \x01(\r\"Q\n\x1f\x45xt4MbReleaseGroupPaFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x11\n\tpa_pstart\x18\x02 \x01(\x04\x12\x0e\n\x06pa_len\x18\x03 \x01(\r\"Y\n\x1f\x45xt4MbReleaseInodePaFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05\x62lock\x18\x03 \x01(\x04\x12\r\n\x05\x63ount\x18\x04 \x01(\r\"\x86\x03\n\x1b\x45xt4MballocAllocFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x14\n\x0corig_logical\x18\x03 \x01(\r\x12\x12\n\norig_start\x18\x04 \x01(\x05\x12\x12\n\norig_group\x18\x05 \x01(\r\x12\x10\n\x08orig_len\x18\x06 \x01(\x05\x12\x14\n\x0cgoal_logical\x18\x07 \x01(\r\x12\x12\n\ngoal_start\x18\x08 \x01(\x05\x12\x12\n\ngoal_group\x18\t \x01(\r\x12\x10\n\x08goal_len\x18\n \x01(\x05\x12\x16\n\x0eresult_logical\x18\x0b \x01(\r\x12\x14\n\x0cresult_start\x18\x0c \x01(\x05\x12\x14\n\x0cresult_group\x18\r \x01(\r\x12\x12\n\nresult_len\x18\x0e \x01(\x05\x12\r\n\x05\x66ound\x18\x0f \x01(\r\x12\x0e\n\x06groups\x18\x10 \x01(\r\x12\r\n\x05\x62uddy\x18\x11 \x01(\r\x12\r\n\x05\x66lags\x18\x12 \x01(\r\x12\x0c\n\x04tail\x18\x13 \x01(\r\x12\n\n\x02\x63r\x18\x14 \x01(\r\"y\n\x1d\x45xt4MballocDiscardFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x14\n\x0cresult_start\x18\x03 \x01(\x05\x12\x14\n\x0cresult_group\x18\x04 \x01(\r\x12\x12\n\nresult_len\x18\x05 \x01(\x05\"v\n\x1a\x45xt4MballocFreeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x14\n\x0cresult_start\x18\x03 \x01(\x05\x12\x14\n\x0cresult_group\x18\x04 \x01(\r\x12\x12\n\nresult_len\x18\x05 \x01(\x05\"\xe2\x01\n\x1e\x45xt4MballocPreallocFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x14\n\x0corig_logical\x18\x03 \x01(\r\x12\x12\n\norig_start\x18\x04 \x01(\x05\x12\x12\n\norig_group\x18\x05 \x01(\r\x12\x10\n\x08orig_len\x18\x06 \x01(\x05\x12\x16\n\x0eresult_logical\x18\x07 \x01(\r\x12\x14\n\x0cresult_start\x18\x08 \x01(\x05\x12\x14\n\x0cresult_group\x18\t \x01(\r\x12\x12\n\nresult_len\x18\n \x01(\x05\"y\n#Ext4OtherInodeUpdateTimeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x10\n\x08orig_ino\x18\x03 \x01(\x04\x12\x0b\n\x03uid\x18\x04 \x01(\r\x12\x0b\n\x03gid\x18\x05 \x01(\r\x12\x0c\n\x04mode\x18\x06 \x01(\r\"_\n\x18\x45xt4PunchHoleFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0e\n\x06offset\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\x03\x12\x0c\n\x04mode\x18\x05 \x01(\x05\"R\n\"Ext4ReadBlockBitmapLoadFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\r\n\x05group\x18\x02 \x01(\r\x12\x10\n\x08prefetch\x18\x03 \x01(\r\"B\n\x17\x45xt4ReadpageFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05index\x18\x03 \x01(\x04\"E\n\x1a\x45xt4ReleasepageFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05index\x18\x03 \x01(\x04\"\xc8\x01\n\x1b\x45xt4RemoveBlocksFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0c\n\x04\x66rom\x18\x03 \x01(\r\x12\n\n\x02to\x18\x04 \x01(\r\x12\x0f\n\x07partial\x18\x05 \x01(\x03\x12\x0f\n\x07\x65\x65_pblk\x18\x06 \x01(\x04\x12\x0f\n\x07\x65\x65_lblk\x18\x07 \x01(\r\x12\x0e\n\x06\x65\x65_len\x18\x08 \x01(\r\x12\x0f\n\x07pc_lblk\x18\t \x01(\r\x12\x0f\n\x07pc_pclu\x18\n \x01(\x04\x12\x10\n\x08pc_state\x18\x0b \x01(\x05\"\xb1\x01\n\x1c\x45xt4RequestBlocksFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03len\x18\x03 \x01(\r\x12\x0f\n\x07logical\x18\x04 \x01(\r\x12\r\n\x05lleft\x18\x05 \x01(\r\x12\x0e\n\x06lright\x18\x06 \x01(\r\x12\x0c\n\x04goal\x18\x07 \x01(\x04\x12\r\n\x05pleft\x18\x08 \x01(\x04\x12\x0e\n\x06pright\x18\t \x01(\x04\x12\r\n\x05\x66lags\x18\n \x01(\r\"E\n\x1b\x45xt4RequestInodeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03\x64ir\x18\x02 \x01(\x04\x12\x0c\n\x04mode\x18\x03 \x01(\r\"2\n\x15\x45xt4SyncFsFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0c\n\x04wait\x18\x02 \x01(\x05\"m\n\x1a\x45xt4TrimAllFreeFtraceEvent\x12\x11\n\tdev_major\x18\x01 \x01(\x05\x12\x11\n\tdev_minor\x18\x02 \x01(\x05\x12\r\n\x05group\x18\x03 \x01(\r\x12\r\n\x05start\x18\x04 \x01(\x05\x12\x0b\n\x03len\x18\x05 \x01(\x05\"l\n\x19\x45xt4TrimExtentFtraceEvent\x12\x11\n\tdev_major\x18\x01 \x01(\x05\x12\x11\n\tdev_minor\x18\x02 \x01(\x05\x12\r\n\x05group\x18\x03 \x01(\r\x12\r\n\x05start\x18\x04 \x01(\x05\x12\x0b\n\x03len\x18\x05 \x01(\x05\"H\n\x1c\x45xt4TruncateEnterFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0e\n\x06\x62locks\x18\x03 \x01(\x04\"G\n\x1b\x45xt4TruncateExitFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0e\n\x06\x62locks\x18\x03 \x01(\x04\"T\n\x1a\x45xt4UnlinkEnterFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0e\n\x06parent\x18\x03 \x01(\x04\x12\x0c\n\x04size\x18\x04 \x01(\x03\"B\n\x19\x45xt4UnlinkExitFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03ret\x18\x03 \x01(\x05\"^\n\x19\x45xt4WriteBeginFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\r\n\x05\x66lags\x18\x05 \x01(\r\"]\n\x17\x45xt4WriteEndFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\r\x12\x0e\n\x06\x63opied\x18\x05 \x01(\r\"C\n\x18\x45xt4WritepageFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\r\n\x05index\x18\x03 \x01(\x04\"\xe0\x01\n\x19\x45xt4WritepagesFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x13\n\x0bnr_to_write\x18\x03 \x01(\x03\x12\x15\n\rpages_skipped\x18\x04 \x01(\x03\x12\x13\n\x0brange_start\x18\x05 \x01(\x03\x12\x11\n\trange_end\x18\x06 \x01(\x03\x12\x17\n\x0fwriteback_index\x18\x07 \x01(\x04\x12\x11\n\tsync_mode\x18\x08 \x01(\x05\x12\x13\n\x0b\x66or_kupdate\x18\t \x01(\r\x12\x14\n\x0crange_cyclic\x18\n \x01(\r\"\xa2\x01\n\x1f\x45xt4WritepagesResultFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0b\n\x03ret\x18\x03 \x01(\x05\x12\x15\n\rpages_written\x18\x04 \x01(\x05\x12\x15\n\rpages_skipped\x18\x05 \x01(\x03\x12\x17\n\x0fwriteback_index\x18\x06 \x01(\x04\x12\x11\n\tsync_mode\x18\x07 \x01(\x05\"_\n\x18\x45xt4ZeroRangeFtraceEvent\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\x04\x12\x0b\n\x03ino\x18\x02 \x01(\x04\x12\x0e\n\x06offset\x18\x03 \x01(\x03\x12\x0b\n\x03len\x18\x04 \x01(\x03\x12\x0c\n\x04mode\x18\x05 \x01(\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.ext4_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EXT4DAWRITEBEGINFTRACEEVENT']._serialized_start=60
  _globals['_EXT4DAWRITEBEGINFTRACEEVENT']._serialized_end=156
  _globals['_EXT4DAWRITEENDFTRACEEVENT']._serialized_start=158
  _globals['_EXT4DAWRITEENDFTRACEEVENT']._serialized_end=253
  _globals['_EXT4SYNCFILEENTERFTRACEEVENT']._serialized_start=255
  _globals['_EXT4SYNCFILEENTERFTRACEEVENT']._serialized_end=345
  _globals['_EXT4SYNCFILEEXITFTRACEEVENT']._serialized_start=347
  _globals['_EXT4SYNCFILEEXITFTRACEEVENT']._serialized_end=415
  _globals['_EXT4ALLOCDABLOCKSFTRACEEVENT']._serialized_start=417
  _globals['_EXT4ALLOCDABLOCKSFTRACEEVENT']._serialized_end=515
  _globals['_EXT4ALLOCATEBLOCKSFTRACEEVENT']._serialized_start=518
  _globals['_EXT4ALLOCATEBLOCKSFTRACEEVENT']._serialized_end=711
  _globals['_EXT4ALLOCATEINODEFTRACEEVENT']._serialized_start=713
  _globals['_EXT4ALLOCATEINODEFTRACEEVENT']._serialized_end=796
  _globals['_EXT4BEGINORDEREDTRUNCATEFTRACEEVENT']._serialized_start=798
  _globals['_EXT4BEGINORDEREDTRUNCATEFTRACEEVENT']._serialized_end=879
  _globals['_EXT4COLLAPSERANGEFTRACEEVENT']._serialized_start=881
  _globals['_EXT4COLLAPSERANGEFTRACEEVENT']._serialized_end=966
  _globals['_EXT4DARELEASESPACEFTRACEEVENT']._serialized_start=969
  _globals['_EXT4DARELEASESPACEFTRACEEVENT']._serialized_end=1171
  _globals['_EXT4DARESERVESPACEFTRACEEVENT']._serialized_start=1174
  _globals['_EXT4DARESERVESPACEFTRACEEVENT']._serialized_end=1342
  _globals['_EXT4DAUPDATERESERVESPACEFTRACEEVENT']._serialized_start=1345
  _globals['_EXT4DAUPDATERESERVESPACEFTRACEEVENT']._serialized_end=1573
  _globals['_EXT4DAWRITEPAGESFTRACEEVENT']._serialized_start=1576
  _globals['_EXT4DAWRITEPAGESFTRACEEVENT']._serialized_end=1783
  _globals['_EXT4DAWRITEPAGESEXTENTFTRACEEVENT']._serialized_start=1785
  _globals['_EXT4DAWRITEPAGESEXTENTFTRACEEVENT']._serialized_end=1888
  _globals['_EXT4DIRECTIOENTERFTRACEEVENT']._serialized_start=1890
  _globals['_EXT4DIRECTIOENTERFTRACEEVENT']._serialized_end=1984
  _globals['_EXT4DIRECTIOEXITFTRACEEVENT']._serialized_start=1986
  _globals['_EXT4DIRECTIOEXITFTRACEEVENT']._serialized_end=2092
  _globals['_EXT4DISCARDBLOCKSFTRACEEVENT']._serialized_start=2094
  _globals['_EXT4DISCARDBLOCKSFTRACEEVENT']._serialized_end=2165
  _globals['_EXT4DISCARDPREALLOCATIONSFTRACEEVENT']._serialized_start=2167
  _globals['_EXT4DISCARDPREALLOCATIONSFTRACEEVENT']._serialized_end=2260
  _globals['_EXT4DROPINODEFTRACEEVENT']._serialized_start=2262
  _globals['_EXT4DROPINODEFTRACEEVENT']._serialized_end=2328
  _globals['_EXT4ESCACHEEXTENTFTRACEEVENT']._serialized_start=2330
  _globals['_EXT4ESCACHEEXTENTFTRACEEVENT']._serialized_end=2443
  _globals['_EXT4ESFINDDELAYEDEXTENTRANGEENTERFTRACEEVENT']._serialized_start=2445
  _globals['_EXT4ESFINDDELAYEDEXTENTRANGEENTERFTRACEEVENT']._serialized_end=2531
  _globals['_EXT4ESFINDDELAYEDEXTENTRANGEEXITFTRACEEVENT']._serialized_start=2534
  _globals['_EXT4ESFINDDELAYEDEXTENTRANGEEXITFTRACEEVENT']._serialized_end=2662
  _globals['_EXT4ESINSERTEXTENTFTRACEEVENT']._serialized_start=2664
  _globals['_EXT4ESINSERTEXTENTFTRACEEVENT']._serialized_end=2778
  _globals['_EXT4ESLOOKUPEXTENTENTERFTRACEEVENT']._serialized_start=2780
  _globals['_EXT4ESLOOKUPEXTENTENTERFTRACEEVENT']._serialized_end=2856
  _globals['_EXT4ESLOOKUPEXTENTEXITFTRACEEVENT']._serialized_start=2859
  _globals['_EXT4ESLOOKUPEXTENTEXITFTRACEEVENT']._serialized_end=2992
  _globals['_EXT4ESREMOVEEXTENTFTRACEEVENT']._serialized_start=2994
  _globals['_EXT4ESREMOVEEXTENTFTRACEEVENT']._serialized_end=3078
  _globals['_EXT4ESSHRINKFTRACEEVENT']._serialized_start=3080
  _globals['_EXT4ESSHRINKFTRACEEVENT']._serialized_end=3193
  _globals['_EXT4ESSHRINKCOUNTFTRACEEVENT']._serialized_start=3195
  _globals['_EXT4ESSHRINKCOUNTFTRACEEVENT']._serialized_end=3277
  _globals['_EXT4ESSHRINKSCANENTERFTRACEEVENT']._serialized_start=3279
  _globals['_EXT4ESSHRINKSCANENTERFTRACEEVENT']._serialized_end=3365
  _globals['_EXT4ESSHRINKSCANEXITFTRACEEVENT']._serialized_start=3367
  _globals['_EXT4ESSHRINKSCANEXITFTRACEEVENT']._serialized_end=3451
  _globals['_EXT4EVICTINODEFTRACEEVENT']._serialized_start=3453
  _globals['_EXT4EVICTINODEFTRACEEVENT']._serialized_end=3521
  _globals['_EXT4EXTCONVERTTOINITIALIZEDENTERFTRACEEVENT']._serialized_start=3524
  _globals['_EXT4EXTCONVERTTOINITIALIZEDENTERFTRACEEVENT']._serialized_end=3673
  _globals['_EXT4EXTCONVERTTOINITIALIZEDFASTPATHFTRACEEVENT']._serialized_start=3676
  _globals['_EXT4EXTCONVERTTOINITIALIZEDFASTPATHFTRACEEVENT']._serialized_end=3875
  _globals['_EXT4EXTHANDLEUNWRITTENEXTENTSFTRACEEVENT']._serialized_start=3878
  _globals['_EXT4EXTHANDLEUNWRITTENEXTENTSFTRACEEVENT']._serialized_end=4037
  _globals['_EXT4EXTINCACHEFTRACEEVENT']._serialized_start=4039
  _globals['_EXT4EXTINCACHEFTRACEEVENT']._serialized_end=4119
  _globals['_EXT4EXTLOADEXTENTFTRACEEVENT']._serialized_start=4121
  _globals['_EXT4EXTLOADEXTENTFTRACEEVENT']._serialized_end=4205
  _globals['_EXT4EXTMAPBLOCKSENTERFTRACEEVENT']._serialized_start=4207
  _globals['_EXT4EXTMAPBLOCKSENTERFTRACEEVENT']._serialized_end=4309
  _globals['_EXT4EXTMAPBLOCKSEXITFTRACEEVENT']._serialized_start=4312
  _globals['_EXT4EXTMAPBLOCKSEXITFTRACEEVENT']._serialized_end=4456
  _globals['_EXT4EXTPUTINCACHEFTRACEEVENT']._serialized_start=4458
  _globals['_EXT4EXTPUTINCACHEFTRACEEVENT']._serialized_end=4556
  _globals['_EXT4EXTREMOVESPACEFTRACEEVENT']._serialized_start=4558
  _globals['_EXT4EXTREMOVESPACEFTRACEEVENT']._serialized_end=4658
  _globals['_EXT4EXTREMOVESPACEDONEFTRACEEVENT']._serialized_start=4661
  _globals['_EXT4EXTREMOVESPACEDONEFTRACEEVENT']._serialized_end=4854
  _globals['_EXT4EXTRMIDXFTRACEEVENT']._serialized_start=4856
  _globals['_EXT4EXTRMIDXFTRACEEVENT']._serialized_end=4921
  _globals['_EXT4EXTRMLEAFFTRACEEVENT']._serialized_start=4924
  _globals['_EXT4EXTRMLEAFFTRACEEVENT']._serialized_end=5110
  _globals['_EXT4EXTSHOWEXTENTFTRACEEVENT']._serialized_start=5112
  _globals['_EXT4EXTSHOWEXTENTFTRACEEVENT']._serialized_end=5209
  _globals['_EXT4FALLOCATEENTERFTRACEEVENT']._serialized_start=5211
  _globals['_EXT4FALLOCATEENTERFTRACEEVENT']._serialized_end=5324
  _globals['_EXT4FALLOCATEEXITFTRACEEVENT']._serialized_start=5326
  _globals['_EXT4FALLOCATEEXITFTRACEEVENT']._serialized_end=5424
  _globals['_EXT4FINDDELALLOCRANGEFTRACEEVENT']._serialized_start=5427
  _globals['_EXT4FINDDELALLOCRANGEFTRACEEVENT']._serialized_end=5564
  _globals['_EXT4FORGETFTRACEEVENT']._serialized_start=5566
  _globals['_EXT4FORGETFTRACEEVENT']._serialized_end=5665
  _globals['_EXT4FREEBLOCKSFTRACEEVENT']._serialized_start=5667
  _globals['_EXT4FREEBLOCKSFTRACEEVENT']._serialized_end=5779
  _globals['_EXT4FREEINODEFTRACEEVENT']._serialized_start=5781
  _globals['_EXT4FREEINODEFTRACEEVENT']._serialized_end=5889
  _globals['_EXT4GETIMPLIEDCLUSTERALLOCEXITFTRACEEVENT']._serialized_start=5891
  _globals['_EXT4GETIMPLIEDCLUSTERALLOCEXITFTRACEEVENT']._serialized_end=6016
  _globals['_EXT4GETRESERVEDCLUSTERALLOCFTRACEEVENT']._serialized_start=6018
  _globals['_EXT4GETRESERVEDCLUSTERALLOCFTRACEEVENT']._serialized_end=6111
  _globals['_EXT4INDMAPBLOCKSENTERFTRACEEVENT']._serialized_start=6113
  _globals['_EXT4INDMAPBLOCKSENTERFTRACEEVENT']._serialized_end=6215
  _globals['_EXT4INDMAPBLOCKSEXITFTRACEEVENT']._serialized_start=6218
  _globals['_EXT4INDMAPBLOCKSEXITFTRACEEVENT']._serialized_end=6362
  _globals['_EXT4INSERTRANGEFTRACEEVENT']._serialized_start=6364
  _globals['_EXT4INSERTRANGEFTRACEEVENT']._serialized_end=6447
  _globals['_EXT4INVALIDATEPAGEFTRACEEVENT']._serialized_start=6449
  _globals['_EXT4INVALIDATEPAGEFTRACEEVENT']._serialized_end=6553
  _globals['_EXT4JOURNALSTARTFTRACEEVENT']._serialized_start=6556
  _globals['_EXT4JOURNALSTARTFTRACEEVENT']._serialized_end=6685
  _globals['_EXT4JOURNALSTARTRESERVEDFTRACEEVENT']._serialized_start=6687
  _globals['_EXT4JOURNALSTARTRESERVEDFTRACEEVENT']._serialized_end=6765
  _globals['_EXT4JOURNALLEDINVALIDATEPAGEFTRACEEVENT']._serialized_start=6767
  _globals['_EXT4JOURNALLEDINVALIDATEPAGEFTRACEEVENT']._serialized_end=6881
  _globals['_EXT4JOURNALLEDWRITEENDFTRACEEVENT']._serialized_start=6883
  _globals['_EXT4JOURNALLEDWRITEENDFTRACEEVENT']._serialized_end=6986
  _globals['_EXT4LOADINODEFTRACEEVENT']._serialized_start=6988
  _globals['_EXT4LOADINODEFTRACEEVENT']._serialized_end=7040
  _globals['_EXT4LOADINODEBITMAPFTRACEEVENT']._serialized_start=7042
  _globals['_EXT4LOADINODEBITMAPFTRACEEVENT']._serialized_end=7102
  _globals['_EXT4MARKINODEDIRTYFTRACEEVENT']._serialized_start=7104
  _globals['_EXT4MARKINODEDIRTYFTRACEEVENT']._serialized_end=7173
  _globals['_EXT4MBBITMAPLOADFTRACEEVENT']._serialized_start=7175
  _globals['_EXT4MBBITMAPLOADFTRACEEVENT']._serialized_end=7232
  _globals['_EXT4MBBUDDYBITMAPLOADFTRACEEVENT']._serialized_start=7234
  _globals['_EXT4MBBUDDYBITMAPLOADFTRACEEVENT']._serialized_end=7296
  _globals['_EXT4MBDISCARDPREALLOCATIONSFTRACEEVENT']._serialized_start=7298
  _globals['_EXT4MBDISCARDPREALLOCATIONSFTRACEEVENT']._serialized_end=7367
  _globals['_EXT4MBNEWGROUPPAFTRACEEVENT']._serialized_start=7369
  _globals['_EXT4MBNEWGROUPPAFTRACEEVENT']._serialized_end=7478
  _globals['_EXT4MBNEWINODEPAFTRACEEVENT']._serialized_start=7480
  _globals['_EXT4MBNEWINODEPAFTRACEEVENT']._serialized_end=7589
  _globals['_EXT4MBRELEASEGROUPPAFTRACEEVENT']._serialized_start=7591
  _globals['_EXT4MBRELEASEGROUPPAFTRACEEVENT']._serialized_end=7672
  _globals['_EXT4MBRELEASEINODEPAFTRACEEVENT']._serialized_start=7674
  _globals['_EXT4MBRELEASEINODEPAFTRACEEVENT']._serialized_end=7763
  _globals['_EXT4MBALLOCALLOCFTRACEEVENT']._serialized_start=7766
  _globals['_EXT4MBALLOCALLOCFTRACEEVENT']._serialized_end=8156
  _globals['_EXT4MBALLOCDISCARDFTRACEEVENT']._serialized_start=8158
  _globals['_EXT4MBALLOCDISCARDFTRACEEVENT']._serialized_end=8279
  _globals['_EXT4MBALLOCFREEFTRACEEVENT']._serialized_start=8281
  _globals['_EXT4MBALLOCFREEFTRACEEVENT']._serialized_end=8399
  _globals['_EXT4MBALLOCPREALLOCFTRACEEVENT']._serialized_start=8402
  _globals['_EXT4MBALLOCPREALLOCFTRACEEVENT']._serialized_end=8628
  _globals['_EXT4OTHERINODEUPDATETIMEFTRACEEVENT']._serialized_start=8630
  _globals['_EXT4OTHERINODEUPDATETIMEFTRACEEVENT']._serialized_end=8751
  _globals['_EXT4PUNCHHOLEFTRACEEVENT']._serialized_start=8753
  _globals['_EXT4PUNCHHOLEFTRACEEVENT']._serialized_end=8848
  _globals['_EXT4READBLOCKBITMAPLOADFTRACEEVENT']._serialized_start=8850
  _globals['_EXT4READBLOCKBITMAPLOADFTRACEEVENT']._serialized_end=8932
  _globals['_EXT4READPAGEFTRACEEVENT']._serialized_start=8934
  _globals['_EXT4READPAGEFTRACEEVENT']._serialized_end=9000
  _globals['_EXT4RELEASEPAGEFTRACEEVENT']._serialized_start=9002
  _globals['_EXT4RELEASEPAGEFTRACEEVENT']._serialized_end=9071
  _globals['_EXT4REMOVEBLOCKSFTRACEEVENT']._serialized_start=9074
  _globals['_EXT4REMOVEBLOCKSFTRACEEVENT']._serialized_end=9274
  _globals['_EXT4REQUESTBLOCKSFTRACEEVENT']._serialized_start=9277
  _globals['_EXT4REQUESTBLOCKSFTRACEEVENT']._serialized_end=9454
  _globals['_EXT4REQUESTINODEFTRACEEVENT']._serialized_start=9456
  _globals['_EXT4REQUESTINODEFTRACEEVENT']._serialized_end=9525
  _globals['_EXT4SYNCFSFTRACEEVENT']._serialized_start=9527
  _globals['_EXT4SYNCFSFTRACEEVENT']._serialized_end=9577
  _globals['_EXT4TRIMALLFREEFTRACEEVENT']._serialized_start=9579
  _globals['_EXT4TRIMALLFREEFTRACEEVENT']._serialized_end=9688
  _globals['_EXT4TRIMEXTENTFTRACEEVENT']._serialized_start=9690
  _globals['_EXT4TRIMEXTENTFTRACEEVENT']._serialized_end=9798
  _globals['_EXT4TRUNCATEENTERFTRACEEVENT']._serialized_start=9800
  _globals['_EXT4TRUNCATEENTERFTRACEEVENT']._serialized_end=9872
  _globals['_EXT4TRUNCATEEXITFTRACEEVENT']._serialized_start=9874
  _globals['_EXT4TRUNCATEEXITFTRACEEVENT']._serialized_end=9945
  _globals['_EXT4UNLINKENTERFTRACEEVENT']._serialized_start=9947
  _globals['_EXT4UNLINKENTERFTRACEEVENT']._serialized_end=10031
  _globals['_EXT4UNLINKEXITFTRACEEVENT']._serialized_start=10033
  _globals['_EXT4UNLINKEXITFTRACEEVENT']._serialized_end=10099
  _globals['_EXT4WRITEBEGINFTRACEEVENT']._serialized_start=10101
  _globals['_EXT4WRITEBEGINFTRACEEVENT']._serialized_end=10195
  _globals['_EXT4WRITEENDFTRACEEVENT']._serialized_start=10197
  _globals['_EXT4WRITEENDFTRACEEVENT']._serialized_end=10290
  _globals['_EXT4WRITEPAGEFTRACEEVENT']._serialized_start=10292
  _globals['_EXT4WRITEPAGEFTRACEEVENT']._serialized_end=10359
  _globals['_EXT4WRITEPAGESFTRACEEVENT']._serialized_start=10362
  _globals['_EXT4WRITEPAGESFTRACEEVENT']._serialized_end=10586
  _globals['_EXT4WRITEPAGESRESULTFTRACEEVENT']._serialized_start=10589
  _globals['_EXT4WRITEPAGESRESULTFTRACEEVENT']._serialized_end=10751
  _globals['_EXT4ZERORANGEFTRACEEVENT']._serialized_start=10753
  _globals['_EXT4ZERORANGEFTRACEEVENT']._serialized_end=10848
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/filesystem/inode_file_map.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/filesystem/inode_file_map.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5protos/perfetto/trace/filesystem/inode_file_map.proto\x12\x0fperfetto.protos\"\x88\x02\n\x0cInodeFileMap\x12\x17\n\x0f\x62lock_device_id\x18\x01 \x01(\x04\x12\x14\n\x0cmount_points\x18\x02 \x03(\t\x12\x34\n\x07\x65ntries\x18\x03 \x03(\x0b\x32#.perfetto.protos.InodeFileMap.Entry\x1a\x92\x01\n\x05\x45ntry\x12\x14\n\x0cinode_number\x18\x01 \x01(\x04\x12\r\n\x05paths\x18\x02 \x03(\t\x12\x36\n\x04type\x18\x03 \x01(\x0e\x32(.perfetto.protos.InodeFileMap.Entry.Type\",\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x46ILE\x10\x01\x12\r\n\tDIRECTORY\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.filesystem.inode_file_map_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INODEFILEMAP']._serialized_start=75
  _globals['_INODEFILEMAP']._serialized_end=339
  _globals['_INODEFILEMAP_ENTRY']._serialized_start=193
  _globals['_INODEFILEMAP_ENTRY']._serialized_end=339
  _globals['_INODEFILEMAP_ENTRY_TYPE']._serialized_start=295
  _globals['_INODEFILEMAP_ENTRY_TYPE']._serialized_end=339
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/gpu/vulkan_memory_event.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/gpu/vulkan_memory_event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3protos/perfetto/trace/gpu/vulkan_memory_event.proto\x12\x0fperfetto.protos\"z\n\x1bVulkanMemoryEventAnnotation\x12\x0f\n\x07key_iid\x18\x01 \x01(\x04\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x12\x14\n\nstring_iid\x18\x04 \x01(\x04H\x00\x42\x07\n\x05value\"\xe8\x06\n\x11VulkanMemoryEvent\x12\x39\n\x06source\x18\x01 \x01(\x0e\x32).perfetto.protos.VulkanMemoryEvent.Source\x12?\n\toperation\x18\x02 \x01(\x0e\x32,.perfetto.protos.VulkanMemoryEvent.Operation\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x0b\n\x03pid\x18\x04 \x01(\r\x12\x16\n\x0ememory_address\x18\x05 \x01(\x06\x12\x13\n\x0bmemory_size\x18\x06 \x01(\x04\x12\x12\n\ncaller_iid\x18\x07 \x01(\x04\x12L\n\x10\x61llocation_scope\x18\x08 \x01(\x0e\x32\x32.perfetto.protos.VulkanMemoryEvent.AllocationScope\x12\x41\n\x0b\x61nnotations\x18\t \x03(\x0b\x32,.perfetto.protos.VulkanMemoryEventAnnotation\x12\x0e\n\x06\x64\x65vice\x18\x10 \x01(\x06\x12\x15\n\rdevice_memory\x18\x11 \x01(\x06\x12\x13\n\x0bmemory_type\x18\x12 \x01(\r\x12\x0c\n\x04heap\x18\x13 \x01(\r\x12\x15\n\robject_handle\x18\x14 \x01(\x06\"\x85\x01\n\x06Source\x12\x16\n\x12SOURCE_UNSPECIFIED\x10\x00\x12\x11\n\rSOURCE_DRIVER\x10\x01\x12\x11\n\rSOURCE_DEVICE\x10\x02\x12\x18\n\x14SOURCE_DEVICE_MEMORY\x10\x03\x12\x11\n\rSOURCE_BUFFER\x10\x04\x12\x10\n\x0cSOURCE_IMAGE\x10\x05\"u\n\tOperation\x12\x12\n\x0eOP_UNSPECIFIED\x10\x00\x12\r\n\tOP_CREATE\x10\x01\x12\x0e\n\nOP_DESTROY\x10\x02\x12\x0b\n\x07OP_BIND\x10\x03\x12\x14\n\x10OP_DESTROY_BOUND\x10\x04\x12\x12\n\x0eOP_ANNOTATIONS\x10\x05\"\x84\x01\n\x0f\x41llocationScope\x12\x15\n\x11SCOPE_UNSPECIFIED\x10\x00\x12\x11\n\rSCOPE_COMMAND\x10\x01\x12\x10\n\x0cSCOPE_OBJECT\x10\x02\x12\x0f\n\x0bSCOPE_CACHE\x10\x03\x12\x10\n\x0cSCOPE_DEVICE\x10\x04\x12\x12\n\x0eSCOPE_INSTANCE\x10\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.gpu.vulkan_memory_event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_VULKANMEMORYEVENTANNOTATION']._serialized_start=72
  _globals['_VULKANMEMORYEVENTANNOTATION']._serialized_end=194
  _globals['_VULKANMEMORYEVENT']._serialized_start=197
  _globals['_VULKANMEMORYEVENT']._serialized_end=1069
  _globals['_VULKANMEMORYEVENT_SOURCE']._serialized_start=682
  _globals['_VULKANMEMORYEVENT_SOURCE']._serialized_end=815
  _globals['_VULKANMEMORYEVENT_OPERATION']._serialized_start=817
  _globals['_VULKANMEMORYEVENT_OPERATION']._serialized_end=934
  _globals['_VULKANMEMORYEVENT_ALLOCATIONSCOPE']._serialized_start=937
  _globals['_VULKANMEMORYEVENT_ALLOCATIONSCOPE']._serialized_end=1069
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/profiling/deobfuscation.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/profiling/deobfuscation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3protos/perfetto/trace/profiling/deobfuscation.proto\x12\x0fperfetto.protos\"F\n\x10ObfuscatedMember\x12\x17\n\x0fobfuscated_name\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65obfuscated_name\x18\x02 \x01(\t\"\xc3\x01\n\x0fObfuscatedClass\x12\x17\n\x0fobfuscated_name\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65obfuscated_name\x18\x02 \x01(\t\x12=\n\x12obfuscated_members\x18\x03 \x03(\x0b\x32!.perfetto.protos.ObfuscatedMember\x12=\n\x12obfuscated_methods\x18\x04 \x03(\x0b\x32!.perfetto.protos.ObfuscatedMember\"\x80\x01\n\x14\x44\x65obfuscationMapping\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x14\n\x0cversion_code\x18\x02 \x01(\x03\x12<\n\x12obfuscated_classes\x18\x03 \x03(\x0b\x32 .perfetto.protos.ObfuscatedClass')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.profiling.deobfuscation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_OBFUSCATEDMEMBER']._serialized_start=72
  _globals['_OBFUSCATEDMEMBER']._serialized_end=142
  _globals['_OBFUSCATEDCLASS']._serialized_start=145
  _globals['_OBFUSCATEDCLASS']._serialized_end=340
  _globals['_DEOBFUSCATIONMAPPING']._serialized_start=343
  _globals['_DEOBFUSCATIONMAPPING']._serialized_end=471
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/config/chrome/chrome_config.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/config/chrome/chrome_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1protos/perfetto/config/chrome/chrome_config.proto\x12\x0fperfetto.protos\"\x92\x02\n\x0c\x43hromeConfig\x12\x14\n\x0ctrace_config\x18\x01 \x01(\t\x12!\n\x19privacy_filtering_enabled\x18\x02 \x01(\x08\x12\x1e\n\x16\x63onvert_to_legacy_json\x18\x03 \x01(\x08\x12\x45\n\x0f\x63lient_priority\x18\x04 \x01(\x0e\x32,.perfetto.protos.ChromeConfig.ClientPriority\x12\x1f\n\x17json_agent_label_filter\x18\x05 \x01(\t\"A\n\x0e\x43lientPriority\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nBACKGROUND\x10\x01\x12\x12\n\x0eUSER_INITIATED\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.config.chrome.chrome_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHROMECONFIG']._serialized_start=71
  _globals['_CHROMECONFIG']._serialized_end=345
  _globals['_CHROMECONFIG_CLIENTPRIORITY']._serialized_start=280
  _globals['_CHROMECONFIG_CLIENTPRIORITY']._serialized_end=345
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/track_event/chrome_renderer_scheduler_state.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/track_event/chrome_renderer_scheduler_state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGprotos/perfetto/trace/track_event/chrome_renderer_scheduler_state.proto\x12\x0fperfetto.protos\"~\n\x1c\x43hromeRendererSchedulerState\x12\x32\n\trail_mode\x18\x01 \x01(\x0e\x32\x1f.perfetto.protos.ChromeRAILMode\x12\x17\n\x0fis_backgrounded\x18\x02 \x01(\x08\x12\x11\n\tis_hidden\x18\x03 \x01(\x08*}\n\x0e\x43hromeRAILMode\x12\x12\n\x0eRAIL_MODE_NONE\x10\x00\x12\x16\n\x12RAIL_MODE_RESPONSE\x10\x01\x12\x17\n\x13RAIL_MODE_ANIMATION\x10\x02\x12\x12\n\x0eRAIL_MODE_IDLE\x10\x03\x12\x12\n\x0eRAIL_MODE_LOAD\x10\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.track_event.chrome_renderer_scheduler_state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHROMERAILMODE']._serialized_start=220
  _globals['_CHROMERAILMODE']._serialized_end=345
  _globals['_CHROMERENDERERSCHEDULERSTATE']._serialized_start=92
  _globals['_CHROMERENDERERSCHEDULERSTATE']._serialized_end=218
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/config/data_source_config.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/config/data_source_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.config.android import android_game_intervention_list_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_android__game__intervention__list__config__pb2
from protos.perfetto.config.android import android_input_event_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_android__input__event__config__pb2
from protos.perfetto.config.android import android_log_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_android__log__config__pb2
from protos.perfetto.config.android import android_polled_state_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_android__polled__state__config__pb2
from protos.perfetto.config.android import android_system_property_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_android__system__property__config__pb2
from protos.perfetto.config.android import android_sdk_sysprop_guard_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_android__sdk__sysprop__guard__config__pb2
from protos.perfetto.config.android import network_trace_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_network__trace__config__pb2
from protos.perfetto.config.android import packages_list_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_packages__list__config__pb2
from protos.perfetto.config.android import pixel_modem_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_pixel__modem__config__pb2
from protos.perfetto.config.android import protolog_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_protolog__config__pb2
from protos.perfetto.config.android import surfaceflinger_layers_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_surfaceflinger__layers__config__pb2
from protos.perfetto.config.android import surfaceflinger_transactions_config_pb2 as protos_dot_perfetto_dot_config_dot_android_dot_surfaceflinger__transactions__config__pb2
from protos.perfetto.config.chrome import chrome_config_pb2 as protos_dot_perfetto_dot_config_dot_chrome_dot_chrome__config__pb2
from protos.perfetto.config.chrome import v8_config_pb2 as protos_dot_perfetto_dot_config_dot_chrome_dot_v8__config__pb2
from protos.perfetto.config.etw import etw_config_pb2 as protos_dot_perfetto_dot_config_dot_etw_dot_etw__config__pb2
from protos.perfetto.config.ftrace import ftrace_config_pb2 as protos_dot_perfetto_dot_config_dot_ftrace_dot_ftrace__config__pb2
from protos.perfetto.config.gpu import gpu_counter_config_pb2 as protos_dot_perfetto_dot_config_dot_gpu_dot_gpu__counter__config__pb2
from protos.perfetto.config.gpu import vulkan_memory_config_pb2 as protos_dot_perfetto_dot_config_dot_gpu_dot_vulkan__memory__config__pb2
from protos.perfetto.config.inode_file import inode_file_config_pb2 as protos_dot_perfetto_dot_config_dot_inode__file_dot_inode__file__config__pb2
from protos.perfetto.config import interceptor_config_pb2 as protos_dot_perfetto_dot_config_dot_interceptor__config__pb2
from protos.perfetto.config.power import android_power_config_pb2 as protos_dot_perfetto_dot_config_dot_power_dot_android__power__config__pb2
from protos.perfetto.config.statsd import statsd_tracing_config_pb2 as protos_dot_perfetto_dot_config_dot_statsd_dot_statsd__tracing__config__pb2
from protos.perfetto.config.process_stats import process_stats_config_pb2 as protos_dot_perfetto_dot_config_dot_process__stats_dot_process__stats__config__pb2
from protos.perfetto.config.profiling import heapprofd_config_pb2 as protos_dot_perfetto_dot_config_dot_profiling_dot_heapprofd__config__pb2
from protos.perfetto.config.profiling import java_hprof_config_pb2 as protos_dot_perfetto_dot_config_dot_profiling_dot_java__hprof__config__pb2
from protos.perfetto.config.profiling import perf_event_config_pb2 as protos_dot_perfetto_dot_config_dot_profiling_dot_perf__event__config__pb2
from protos.perfetto.config.sys_stats import sys_stats_config_pb2 as protos_dot_perfetto_dot_config_dot_sys__stats_dot_sys__stats__config__pb2
from protos.perfetto.config import test_config_pb2 as protos_dot_perfetto_dot_config_dot_test__config__pb2
from protos.perfetto.config.track_event import track_event_config_pb2 as protos_dot_perfetto_dot_config_dot_track__event_dot_track__event__config__pb2
from protos.perfetto.config.system_info import system_info_pb2 as protos_dot_perfetto_dot_config_dot_system__info_dot_system__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/protos/perfetto/config/data_source_config.proto\x12\x0fperfetto.protos\x1aJprotos/perfetto/config/android/android_game_intervention_list_config.proto\x1a?protos/perfetto/config/android/android_input_event_config.proto\x1a\x37protos/perfetto/config/android/android_log_config.proto\x1a@protos/perfetto/config/android/android_polled_state_config.proto\x1a\x43protos/perfetto/config/android/android_system_property_config.proto\x1a\x45protos/perfetto/config/android/android_sdk_sysprop_guard_config.proto\x1a\x39protos/perfetto/config/android/network_trace_config.proto\x1a\x39protos/perfetto/config/android/packages_list_config.proto\x1a\x37protos/perfetto/config/android/pixel_modem_config.proto\x1a\x34protos/perfetto/config/android/protolog_config.proto\x1a\x41protos/perfetto/config/android/surfaceflinger_layers_config.proto\x1aGprotos/perfetto/config/android/surfaceflinger_transactions_config.proto\x1a\x31protos/perfetto/config/chrome/chrome_config.proto\x1a-protos/perfetto/config/chrome/v8_config.proto\x1a+protos/perfetto/config/etw/etw_config.proto\x1a\x31protos/perfetto/config/ftrace/ftrace_config.proto\x1a\x33protos/perfetto/config/gpu/gpu_counter_config.proto\x1a\x35protos/perfetto/config/gpu/vulkan_memory_config.proto\x1a\x39protos/perfetto/config/inode_file/inode_file_config.proto\x1a/protos/perfetto/config/interceptor_config.proto\x1a\x37protos/perfetto/config/power/android_power_config.proto\x1a\x39protos/perfetto/config/statsd/statsd_tracing_config.proto\x1a?protos/perfetto/config/process_stats/process_stats_config.proto\x1a\x37protos/perfetto/config/profiling/heapprofd_config.proto\x1a\x38protos/perfetto/config/profiling/java_hprof_config.proto\x1a\x38protos/perfetto/config/profiling/perf_event_config.proto\x1a\x37protos/perfetto/config/sys_stats/sys_stats_config.proto\x1a(protos/perfetto/config/test_config.proto\x1a;protos/perfetto/config/track_event/track_event_config.proto\x1a\x34protos/perfetto/config/system_info/system_info.proto\"\xf1\x13\n\x10\x44\x61taSourceConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rtarget_buffer\x18\x02 \x01(\r\x12\x19\n\x11trace_duration_ms\x18\x03 \x01(\r\x12)\n!prefer_suspend_clock_for_duration\x18z \x01(\x08\x12\x17\n\x0fstop_timeout_ms\x18\x07 \x01(\r\x12\x1f\n\x17\x65nable_extra_guardrails\x18\x06 \x01(\x08\x12M\n\x11session_initiator\x18\x08 \x01(\x0e\x32\x32.perfetto.protos.DataSourceConfig.SessionInitiator\x12\x1a\n\x12tracing_session_id\x18\x04 \x01(\x04\x12\x38\n\rftrace_config\x18\x64 \x01(\x0b\x32\x1d.perfetto.protos.FtraceConfigB\x02(\x01\x12?\n\x11inode_file_config\x18\x66 \x01(\x0b\x32 .perfetto.protos.InodeFileConfigB\x02(\x01\x12\x45\n\x14process_stats_config\x18g \x01(\x0b\x32#.perfetto.protos.ProcessStatsConfigB\x02(\x01\x12=\n\x10sys_stats_config\x18h \x01(\x0b\x32\x1f.perfetto.protos.SysStatsConfigB\x02(\x01\x12>\n\x10heapprofd_config\x18i \x01(\x0b\x32 .perfetto.protos.HeapprofdConfigB\x02(\x01\x12?\n\x11java_hprof_config\x18n \x01(\x0b\x32 .perfetto.protos.JavaHprofConfigB\x02(\x01\x12\x45\n\x14\x61ndroid_power_config\x18j \x01(\x0b\x32#.perfetto.protos.AndroidPowerConfigB\x02(\x01\x12\x41\n\x12\x61ndroid_log_config\x18k \x01(\x0b\x32!.perfetto.protos.AndroidLogConfigB\x02(\x01\x12\x41\n\x12gpu_counter_config\x18l \x01(\x0b\x32!.perfetto.protos.GpuCounterConfigB\x02(\x01\x12\x65\n%android_game_intervention_list_config\x18t \x01(\x0b\x32\x32.perfetto.protos.AndroidGameInterventionListConfigB\x02(\x01\x12\x45\n\x14packages_list_config\x18m \x01(\x0b\x32#.perfetto.protos.PackagesListConfigB\x02(\x01\x12?\n\x11perf_event_config\x18o \x01(\x0b\x32 .perfetto.protos.PerfEventConfigB\x02(\x01\x12\x45\n\x14vulkan_memory_config\x18p \x01(\x0b\x32#.perfetto.protos.VulkanMemoryConfigB\x02(\x01\x12\x41\n\x12track_event_config\x18q \x01(\x0b\x32!.perfetto.protos.TrackEventConfigB\x02(\x01\x12R\n\x1b\x61ndroid_polled_state_config\x18r \x01(\x0b\x32).perfetto.protos.AndroidPolledStateConfigB\x02(\x01\x12X\n\x1e\x61ndroid_system_property_config\x18v \x01(\x0b\x32,.perfetto.protos.AndroidSystemPropertyConfigB\x02(\x01\x12G\n\x15statsd_tracing_config\x18u \x01(\x0b\x32$.perfetto.protos.StatsdTracingConfigB\x02(\x01\x12=\n\x12system_info_config\x18w \x01(\x0b\x32!.perfetto.protos.SystemInfoConfig\x12\x34\n\rchrome_config\x18\x65 \x01(\x0b\x32\x1d.perfetto.protos.ChromeConfig\x12\x30\n\tv8_config\x18\x7f \x01(\x0b\x32\x19.perfetto.protos.V8ConfigB\x02(\x01\x12>\n\x12interceptor_config\x18s \x01(\x0b\x32\".perfetto.protos.InterceptorConfig\x12R\n\x1bnetwork_packet_trace_config\x18x \x01(\x0b\x32).perfetto.protos.NetworkPacketTraceConfigB\x02(\x01\x12U\n\x1csurfaceflinger_layers_config\x18y \x01(\x0b\x32+.perfetto.protos.SurfaceFlingerLayersConfigB\x02(\x01\x12\x61\n\"surfaceflinger_transactions_config\x18{ \x01(\x0b\x32\x31.perfetto.protos.SurfaceFlingerTransactionsConfigB\x02(\x01\x12[\n android_sdk_sysprop_guard_config\x18| \x01(\x0b\x32-.perfetto.protos.AndroidSdkSyspropGuardConfigB\x02(\x01\x12\x32\n\netw_config\x18} \x01(\x0b\x32\x1a.perfetto.protos.EtwConfigB\x02(\x01\x12<\n\x0fprotolog_config\x18~ \x01(\x0b\x32\x1f.perfetto.protos.ProtoLogConfigB\x02(\x01\x12Q\n\x1a\x61ndroid_input_event_config\x18\x80\x01 \x01(\x0b\x32(.perfetto.protos.AndroidInputEventConfigB\x02(\x01\x12\x42\n\x12pixel_modem_config\x18\x81\x01 \x01(\x0b\x32!.perfetto.protos.PixelModemConfigB\x02(\x01\x12\x16\n\rlegacy_config\x18\xe8\x07 \x01(\t\x12\x31\n\x0b\x66or_testing\x18\xe9\x07 \x01(\x0b\x32\x1b.perfetto.protos.TestConfig\"[\n\x10SessionInitiator\x12!\n\x1dSESSION_INITIATOR_UNSPECIFIED\x10\x00\x12$\n SESSION_INITIATOR_TRUSTED_SYSTEM\x10\x01J\x0b\x08\xff\xff\xff\x7f\x10\x80\x80\x80\x80\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.config.data_source_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['ftrace_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['ftrace_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['inode_file_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['inode_file_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['process_stats_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['process_stats_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['sys_stats_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['sys_stats_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['heapprofd_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['heapprofd_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['java_hprof_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['java_hprof_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['android_power_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['android_power_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['android_log_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['android_log_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['gpu_counter_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['gpu_counter_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['android_game_intervention_list_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['android_game_intervention_list_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['packages_list_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['packages_list_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['perf_event_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['perf_event_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['vulkan_memory_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['vulkan_memory_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['track_event_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['track_event_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['android_polled_state_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['android_polled_state_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['android_system_property_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['android_system_property_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['statsd_tracing_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['statsd_tracing_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['v8_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['v8_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['network_packet_trace_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['network_packet_trace_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['surfaceflinger_layers_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['surfaceflinger_layers_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['surfaceflinger_transactions_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['surfaceflinger_transactions_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['android_sdk_sysprop_guard_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['android_sdk_sysprop_guard_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['etw_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['etw_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['protolog_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['protolog_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['android_input_event_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['android_input_event_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG'].fields_by_name['pixel_modem_config']._loaded_options = None
  _globals['_DATASOURCECONFIG'].fields_by_name['pixel_modem_config']._serialized_options = b'(\001'
  _globals['_DATASOURCECONFIG']._serialized_start=1820
  _globals['_DATASOURCECONFIG']._serialized_end=4365
  _globals['_DATASOURCECONFIG_SESSIONINITIATOR']._serialized_start=4261
  _globals['_DATASOURCECONFIG_SESSIONINITIATOR']._serialized_end=4352
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/compaction.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/compaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-protos/perfetto/trace/ftrace/compaction.proto\x12\x0fperfetto.protos\"y\n\x1cMmCompactionBeginFtraceEvent\x12\x12\n\nzone_start\x18\x01 \x01(\x04\x12\x13\n\x0bmigrate_pfn\x18\x02 \x01(\x04\x12\x10\n\x08\x66ree_pfn\x18\x03 \x01(\x04\x12\x10\n\x08zone_end\x18\x04 \x01(\x04\x12\x0c\n\x04sync\x18\x05 \x01(\r\"\x90\x01\n&MmCompactionDeferCompactionFtraceEvent\x12\x0b\n\x03nid\x18\x01 \x01(\x05\x12\x0b\n\x03idx\x18\x02 \x01(\r\x12\r\n\x05order\x18\x03 \x01(\x05\x12\x12\n\nconsidered\x18\x04 \x01(\r\x12\x13\n\x0b\x64\x65\x66\x65r_shift\x18\x05 \x01(\r\x12\x14\n\x0corder_failed\x18\x06 \x01(\x05\"\x89\x01\n\x1fMmCompactionDeferredFtraceEvent\x12\x0b\n\x03nid\x18\x01 \x01(\x05\x12\x0b\n\x03idx\x18\x02 \x01(\r\x12\r\n\x05order\x18\x03 \x01(\x05\x12\x12\n\nconsidered\x18\x04 \x01(\r\x12\x13\n\x0b\x64\x65\x66\x65r_shift\x18\x05 \x01(\r\x12\x14\n\x0corder_failed\x18\x06 \x01(\x05\"\x8b\x01\n!MmCompactionDeferResetFtraceEvent\x12\x0b\n\x03nid\x18\x01 \x01(\x05\x12\x0b\n\x03idx\x18\x02 \x01(\r\x12\r\n\x05order\x18\x03 \x01(\x05\x12\x12\n\nconsidered\x18\x04 \x01(\r\x12\x13\n\x0b\x64\x65\x66\x65r_shift\x18\x05 \x01(\r\x12\x14\n\x0corder_failed\x18\x06 \x01(\x05\"\x87\x01\n\x1aMmCompactionEndFtraceEvent\x12\x12\n\nzone_start\x18\x01 \x01(\x04\x12\x13\n\x0bmigrate_pfn\x18\x02 \x01(\x04\x12\x10\n\x08\x66ree_pfn\x18\x03 \x01(\x04\x12\x10\n\x08zone_end\x18\x04 \x01(\x04\x12\x0c\n\x04sync\x18\x05 \x01(\r\x12\x0e\n\x06status\x18\x06 \x01(\x05\"W\n\x1fMmCompactionFinishedFtraceEvent\x12\x0b\n\x03nid\x18\x01 \x01(\x05\x12\x0b\n\x03idx\x18\x02 \x01(\r\x12\r\n\x05order\x18\x03 \x01(\x05\x12\x0b\n\x03ret\x18\x04 \x01(\x05\"s\n\'MmCompactionIsolateFreepagesFtraceEvent\x12\x11\n\tstart_pfn\x18\x01 \x01(\x04\x12\x0f\n\x07\x65nd_pfn\x18\x02 \x01(\x04\x12\x12\n\nnr_scanned\x18\x03 \x01(\x04\x12\x10\n\x08nr_taken\x18\x04 \x01(\x04\"v\n*MmCompactionIsolateMigratepagesFtraceEvent\x12\x11\n\tstart_pfn\x18\x01 \x01(\x04\x12\x0f\n\x07\x65nd_pfn\x18\x02 \x01(\x04\x12\x12\n\nnr_scanned\x18\x03 \x01(\x04\x12\x10\n\x08nr_taken\x18\x04 \x01(\x04\"4\n%MmCompactionKcompactdSleepFtraceEvent\x12\x0b\n\x03nid\x18\x01 \x01(\x05\"r\n$MmCompactionKcompactdWakeFtraceEvent\x12\x0b\n\x03nid\x18\x01 \x01(\x05\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x15\n\rclasszone_idx\x18\x03 \x01(\r\x12\x17\n\x0fhighest_zoneidx\x18\x04 \x01(\r\"M\n#MmCompactionMigratepagesFtraceEvent\x12\x13\n\x0bnr_migrated\x18\x01 \x01(\x04\x12\x11\n\tnr_failed\x18\x02 \x01(\x04\"W\n\x1fMmCompactionSuitableFtraceEvent\x12\x0b\n\x03nid\x18\x01 \x01(\x05\x12\x0b\n\x03idx\x18\x02 \x01(\r\x12\r\n\x05order\x18\x03 \x01(\x05\x12\x0b\n\x03ret\x18\x04 \x01(\x05\"g\n(MmCompactionTryToCompactPagesFtraceEvent\x12\r\n\x05order\x18\x01 \x01(\x05\x12\x10\n\x08gfp_mask\x18\x02 \x01(\r\x12\x0c\n\x04mode\x18\x03 \x01(\r\x12\x0c\n\x04prio\x18\x04 \x01(\x05\"t\n&MmCompactionWakeupKcompactdFtraceEvent\x12\x0b\n\x03nid\x18\x01 \x01(\x05\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x15\n\rclasszone_idx\x18\x03 \x01(\r\x12\x17\n\x0fhighest_zoneidx\x18\x04 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.compaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MMCOMPACTIONBEGINFTRACEEVENT']._serialized_start=66
  _globals['_MMCOMPACTIONBEGINFTRACEEVENT']._serialized_end=187
  _globals['_MMCOMPACTIONDEFERCOMPACTIONFTRACEEVENT']._serialized_start=190
  _globals['_MMCOMPACTIONDEFERCOMPACTIONFTRACEEVENT']._serialized_end=334
  _globals['_MMCOMPACTIONDEFERREDFTRACEEVENT']._serialized_start=337
  _globals['_MMCOMPACTIONDEFERREDFTRACEEVENT']._serialized_end=474
  _globals['_MMCOMPACTIONDEFERRESETFTRACEEVENT']._serialized_start=477
  _globals['_MMCOMPACTIONDEFERRESETFTRACEEVENT']._serialized_end=616
  _globals['_MMCOMPACTIONENDFTRACEEVENT']._serialized_start=619
  _globals['_MMCOMPACTIONENDFTRACEEVENT']._serialized_end=754
  _globals['_MMCOMPACTIONFINISHEDFTRACEEVENT']._serialized_start=756
  _globals['_MMCOMPACTIONFINISHEDFTRACEEVENT']._serialized_end=843
  _globals['_MMCOMPACTIONISOLATEFREEPAGESFTRACEEVENT']._serialized_start=845
  _globals['_MMCOMPACTIONISOLATEFREEPAGESFTRACEEVENT']._serialized_end=960
  _globals['_MMCOMPACTIONISOLATEMIGRATEPAGESFTRACEEVENT']._serialized_start=962
  _globals['_MMCOMPACTIONISOLATEMIGRATEPAGESFTRACEEVENT']._serialized_end=1080
  _globals['_MMCOMPACTIONKCOMPACTDSLEEPFTRACEEVENT']._serialized_start=1082
  _globals['_MMCOMPACTIONKCOMPACTDSLEEPFTRACEEVENT']._serialized_end=1134
  _globals['_MMCOMPACTIONKCOMPACTDWAKEFTRACEEVENT']._serialized_start=1136
  _globals['_MMCOMPACTIONKCOMPACTDWAKEFTRACEEVENT']._serialized_end=1250
  _globals['_MMCOMPACTIONMIGRATEPAGESFTRACEEVENT']._serialized_start=1252
  _globals['_MMCOMPACTIONMIGRATEPAGESFTRACEEVENT']._serialized_end=1329
  _globals['_MMCOMPACTIONSUITABLEFTRACEEVENT']._serialized_start=1331
  _globals['_MMCOMPACTIONSUITABLEFTRACEEVENT']._serialized_end=1418
  _globals['_MMCOMPACTIONTRYTOCOMPACTPAGESFTRACEEVENT']._serialized_start=1420
  _globals['_MMCOMPACTIONTRYTOCOMPACTPAGESFTRACEEVENT']._serialized_end=1523
  _globals['_MMCOMPACTIONWAKEUPKCOMPACTDFTRACEEVENT']._serialized_start=1525
  _globals['_MMCOMPACTIONWAKEUPKCOMPACTDFTRACEEVENT']._serialized_end=1641
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/config/test_config.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/config/test_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(protos/perfetto/config/test_config.proto\x12\x0fperfetto.protos\"\x8d\x04\n\nTestConfig\x12\x15\n\rmessage_count\x18\x01 \x01(\r\x12\x1f\n\x17max_messages_per_second\x18\x02 \x01(\r\x12\x0c\n\x04seed\x18\x03 \x01(\r\x12\x14\n\x0cmessage_size\x18\x04 \x01(\r\x12\x1e\n\x16send_batch_on_register\x18\x05 \x01(\x08\x12=\n\x0c\x64ummy_fields\x18\x06 \x01(\x0b\x32\'.perfetto.protos.TestConfig.DummyFields\x1a\xc3\x02\n\x0b\x44ummyFields\x12\x14\n\x0c\x66ield_uint32\x18\x01 \x01(\r\x12\x13\n\x0b\x66ield_int32\x18\x02 \x01(\x05\x12\x14\n\x0c\x66ield_uint64\x18\x03 \x01(\x04\x12\x13\n\x0b\x66ield_int64\x18\x04 \x01(\x03\x12\x15\n\rfield_fixed64\x18\x05 \x01(\x06\x12\x16\n\x0e\x66ield_sfixed64\x18\x06 \x01(\x10\x12\x15\n\rfield_fixed32\x18\x07 \x01(\x07\x12\x16\n\x0e\x66ield_sfixed32\x18\x08 \x01(\x0f\x12\x14\n\x0c\x66ield_double\x18\t \x01(\x01\x12\x13\n\x0b\x66ield_float\x18\n \x01(\x02\x12\x14\n\x0c\x66ield_sint64\x18\x0b \x01(\x12\x12\x14\n\x0c\x66ield_sint32\x18\x0c \x01(\x11\x12\x14\n\x0c\x66ield_string\x18\r \x01(\t\x12\x13\n\x0b\x66ield_bytes\x18\x0e \x01(\x0c')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.config.test_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TESTCONFIG']._serialized_start=62
  _globals['_TESTCONFIG']._serialized_end=587
  _globals['_TESTCONFIG_DUMMYFIELDS']._serialized_start=264
  _globals['_TESTCONFIG_DUMMYFIELDS']._serialized_end=587
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/config/android/pixel_modem_config.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/config/android/pixel_modem_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7protos/perfetto/config/android/pixel_modem_config.proto\x12\x0fperfetto.protos\"\x84\x02\n\x10PixelModemConfig\x12\x41\n\x0b\x65vent_group\x18\x01 \x01(\x0e\x32,.perfetto.protos.PixelModemConfig.EventGroup\x12\x1f\n\x17pigweed_hash_allow_list\x18\x02 \x03(\x03\x12\x1e\n\x16pigweed_hash_deny_list\x18\x03 \x03(\x03\"l\n\nEventGroup\x12\x17\n\x13\x45VENT_GROUP_UNKNOWN\x10\x00\x12\x1d\n\x19\x45VENT_GROUP_LOW_BANDWIDTH\x10\x01\x12&\n\"EVENT_GROUP_HIGH_AND_LOW_BANDWIDTH\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.config.android.pixel_modem_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PIXELMODEMCONFIG']._serialized_start=77
  _globals['_PIXELMODEMCONFIG']._serialized_end=337
  _globals['_PIXELMODEMCONFIG_EVENTGROUP']._serialized_start=229
  _globals['_PIXELMODEMCONFIG_EVENTGROUP']._serialized_end=337
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/track_event/chrome_frame_reporter.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/track_event/chrome_frame_reporter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=protos/perfetto/trace/track_event/chrome_frame_reporter.proto\x12\x0fperfetto.protos\"\xc5\x07\n\x13\x43hromeFrameReporter\x12\x39\n\x05state\x18\x01 \x01(\x0e\x32*.perfetto.protos.ChromeFrameReporter.State\x12\x44\n\x06reason\x18\x02 \x01(\x0e\x32\x34.perfetto.protos.ChromeFrameReporter.FrameDropReason\x12\x14\n\x0c\x66rame_source\x18\x03 \x01(\x04\x12\x16\n\x0e\x66rame_sequence\x18\x04 \x01(\x04\x12\x1a\n\x12\x61\x66\x66\x65\x63ts_smoothness\x18\x05 \x01(\x08\x12\x46\n\x0cscroll_state\x18\x06 \x01(\x0e\x32\x30.perfetto.protos.ChromeFrameReporter.ScrollState\x12\x1a\n\x12has_main_animation\x18\x07 \x01(\x08\x12 \n\x18has_compositor_animation\x18\x08 \x01(\x08\x12\x1d\n\x15has_smooth_input_main\x18\t \x01(\x08\x12\x1b\n\x13has_missing_content\x18\n \x01(\x08\x12\x1a\n\x12layer_tree_host_id\x18\x0b \x01(\x04\x12\x18\n\x10has_high_latency\x18\x0c \x01(\x08\x12\x42\n\nframe_type\x18\r \x01(\x0e\x32..perfetto.protos.ChromeFrameReporter.FrameType\x12\'\n\x1fhigh_latency_contribution_stage\x18\x0e \x03(\t\"m\n\x05State\x12\x1b\n\x17STATE_NO_UPDATE_DESIRED\x10\x00\x12\x17\n\x13STATE_PRESENTED_ALL\x10\x01\x12\x1b\n\x17STATE_PRESENTED_PARTIAL\x10\x02\x12\x11\n\rSTATE_DROPPED\x10\x03\"~\n\x0f\x46rameDropReason\x12\x16\n\x12REASON_UNSPECIFIED\x10\x00\x12\x1d\n\x19REASON_DISPLAY_COMPOSITOR\x10\x01\x12\x16\n\x12REASON_MAIN_THREAD\x10\x02\x12\x1c\n\x18REASON_CLIENT_COMPOSITOR\x10\x03\"h\n\x0bScrollState\x12\x0f\n\x0bSCROLL_NONE\x10\x00\x12\x16\n\x12SCROLL_MAIN_THREAD\x10\x01\x12\x1c\n\x18SCROLL_COMPOSITOR_THREAD\x10\x02\x12\x12\n\x0eSCROLL_UNKNOWN\x10\x03\"%\n\tFrameType\x12\n\n\x06\x46ORKED\x10\x00\x12\x0c\n\x08\x42\x41\x43KFILL\x10\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.track_event.chrome_frame_reporter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHROMEFRAMEREPORTER']._serialized_start=83
  _globals['_CHROMEFRAMEREPORTER']._serialized_end=1048
  _globals['_CHROMEFRAMEREPORTER_STATE']._serialized_start=666
  _globals['_CHROMEFRAMEREPORTER_STATE']._serialized_end=775
  _globals['_CHROMEFRAMEREPORTER_FRAMEDROPREASON']._serialized_start=777
  _globals['_CHROMEFRAMEREPORTER_FRAMEDROPREASON']._serialized_end=903
  _globals['_CHROMEFRAMEREPORTER_SCROLLSTATE']._serialized_start=905
  _globals['_CHROMEFRAMEREPORTER_SCROLLSTATE']._serialized_end=1009
  _globals['_CHROMEFRAMEREPORTER_FRAMETYPE']._serialized_start=1011
  _globals['_CHROMEFRAMEREPORTER_FRAMETYPE']._serialized_end=1048
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/etw/etw_event.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/etw/etw_event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.trace.etw import etw_pb2 as protos_dot_perfetto_dot_trace_dot_etw_dot_etw__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)protos/perfetto/trace/etw/etw_event.proto\x12\x0fperfetto.protos\x1a#protos/perfetto/trace/etw/etw.proto\"\xac\x01\n\rEtwTraceEvent\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x0b\n\x03\x63pu\x18\x04 \x01(\r\x12\x34\n\x08\x63_switch\x18\x02 \x01(\x0b\x32 .perfetto.protos.CSwitchEtwEventH\x00\x12<\n\x0cready_thread\x18\x03 \x01(\x0b\x32$.perfetto.protos.ReadyThreadEtwEventH\x00\x42\x07\n\x05\x65vent')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.etw.etw_event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ETWTRACEEVENT']._serialized_start=100
  _globals['_ETWTRACEEVENT']._serialized_end=272
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/regulator.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/regulator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,protos/perfetto/trace/ftrace/regulator.proto\x12\x0fperfetto.protos\"+\n\x1bRegulatorDisableFtraceEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\"3\n#RegulatorDisableCompleteFtraceEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\"*\n\x1aRegulatorEnableFtraceEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\"2\n\"RegulatorEnableCompleteFtraceEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\"/\n\x1fRegulatorEnableDelayFtraceEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\"H\n\x1eRegulatorSetVoltageFtraceEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03min\x18\x02 \x01(\x05\x12\x0b\n\x03max\x18\x03 \x01(\x05\"C\n&RegulatorSetVoltageCompleteFtraceEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03val\x18\x02 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.regulator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REGULATORDISABLEFTRACEEVENT']._serialized_start=65
  _globals['_REGULATORDISABLEFTRACEEVENT']._serialized_end=108
  _globals['_REGULATORDISABLECOMPLETEFTRACEEVENT']._serialized_start=110
  _globals['_REGULATORDISABLECOMPLETEFTRACEEVENT']._serialized_end=161
  _globals['_REGULATORENABLEFTRACEEVENT']._serialized_start=163
  _globals['_REGULATORENABLEFTRACEEVENT']._serialized_end=205
  _globals['_REGULATORENABLECOMPLETEFTRACEEVENT']._serialized_start=207
  _globals['_REGULATORENABLECOMPLETEFTRACEEVENT']._serialized_end=257
  _globals['_REGULATORENABLEDELAYFTRACEEVENT']._serialized_start=259
  _globals['_REGULATORENABLEDELAYFTRACEEVENT']._serialized_end=306
  _globals['_REGULATORSETVOLTAGEFTRACEEVENT']._serialized_start=308
  _globals['_REGULATORSETVOLTAGEFTRACEEVENT']._serialized_end=380
  _globals['_REGULATORSETVOLTAGECOMPLETEFTRACEEVENT']._serialized_start=382
  _globals['_REGULATORSETVOLTAGECOMPLETEFTRACEEVENT']._serialized_end=449
# @@protoc_insertion_point(module_scope)
